# eric7.WebBrowser.FeaturePermissions.FeaturePermissionManager

Module implementing the feature permission manager object.

### Global Attributes

None

### Classes

FeaturePermissionManager | Class implementing the feature permission manager object.

### Functions

None

## FeaturePermissionManager

Class implementing the feature permission manager object.

### Derived from

QObject

### Class Attributes

SettingsKeyFormat

### Class Methods

None

### Methods

FeaturePermissionManager | Constructor
__loadSettings | Private method to load the remembered feature permissions.
__saveSettings | Private method to save the remembered feature permissions.
rememberFeaturePermission | Public method to remember a user decision for a feature permission.
requestFeaturePermission | Public method to request a feature permission.
showFeaturePermissionsDialog | Public method to show a dialog to manage the remembered feature permissions.

### Static Methods

None

#### FeaturePermissionManager (Constructor)

FeaturePermissionManager(parent=None)

Constructor

parent (QObject)
  reference to the parent object

#### FeaturePermissionManager.__loadSettings

__loadSettings()

Private method to load the remembered feature permissions.

#### FeaturePermissionManager.__saveSettings

__saveSettings()

Private method to save the remembered feature permissions.

#### FeaturePermissionManager.rememberFeaturePermission

rememberFeaturePermission(host, feature, permission)

Public method to remember a user decision for a feature permission.

host (str)
  host name to remember the decision for
feature (QWebEnginePage.Feature)
  feature to be remembered
permission (QWebEnginePage.PermissionPolicy)
  feature permission to be remembered

#### FeaturePermissionManager.requestFeaturePermission

requestFeaturePermission(page, origin, feature)

Public method to request a feature permission.

page (QWebEnginePage)
  reference to the requesting web page
origin (QUrl)
  security origin requesting the feature
feature (QWebEnginePage.Feature)
  requested feature

#### FeaturePermissionManager.showFeaturePermissionsDialog

showFeaturePermissionsDialog()

Public method to show a dialog to manage the remembered feature permissions.

Up